@@ -12,11 +12,11 @@ function(x, ...)
     res1 <- cbind(Name, Description)    
     cat("This function calculates PLS-PM for global and local models", "\n")
     cat("-----------------------------------------------------------", "\n")    
-    cat("  Number of classes", "\t", length(x)-1,"\n")
-    cat("  Scale of Data", "\t", Scale, "\n")
-    cat("  Weighting Scheme", "\t", model$scheme, "\n")
-    cat("  Tolerance Crit", "\t", model$tol, "\n")
-    cat("  Max Num of Iters", "\t", model$iter, "\n")
+    cat("  Number of classes  ", length(x)-1,"\n")
+    cat("  Scale of Data      ", Scale, "\n")
+    cat("  Weighting Scheme   ", model$scheme, "\n")
+    cat("  Tolerance Crit     ", model$tol, "\n")
+    cat("  Max Num of Iters   ", model$iter, "\n")
     cat("\n")
     cat("PLS-PM models in the following objects", "\n")
     rownames(res1) <- 1:nrow(res1)
